import * as _nuxt_schema from '@nuxt/schema';

declare const _default: _nuxt_schema.NuxtModule<ShopwareNuxtOptions, ShopwareNuxtOptions, false>;

type ShopwareNuxtOptions = {
    /**
     * Endpoint for your shopware backend.
     *
     * Default demo store: "https://demo-frontends.swstage.store/"
     */
    endpoint?: string;
    shopwareEndpoint?: string;
    accessToken?: string;
    shopwareAccessToken?: string;
    devStorefrontUrl?: string;
    apiClientConfig?: {
        timeout?: number | string;
    };
    /**
     * Use user context in SSR mode. Warning: with wrong edge caching it can cause serving another user's data.
     * Use when edge caching is configured properly.
     *
     * @default false
     */
    useUserContextInSSR?: boolean;
};
declare module "@nuxt/schema" {
    interface NuxtConfig {
        shopware?: ShopwareNuxtOptions;
    }
    interface NuxtOptions {
        shopware?: ShopwareNuxtOptions;
    }
    interface ApiClientConfig {
        headers?: {
            [key: string]: string;
        };
    }
    interface RuntimeConfig {
        shopware?: Pick<ShopwareNuxtOptions, "endpoint" | "shopwareEndpoint" | "useUserContextInSSR">;
        apiClientConfig?: ApiClientConfig;
    }
    interface PublicRuntimeConfig {
        shopware: ShopwareNuxtOptions;
        apiClientConfig?: ApiClientConfig;
    }
}

export { type ShopwareNuxtOptions, _default as default };
